@@ -1,15 +1,13 @@
 import kate
 import simplejson
 import pprint
-import utils
 
-from kate_settings_plugins import kate_plugins_settings
-
-from simplejson import JSONDecodeError
+from kate_core_plugins import insertText
+from kate_settings_plugins import KATE_ACTIONS
 
 
 #http://www.muhuk.com/2008/11/extending-kate-with-pate/
-@kate.action(**kate_plugins_settings['togglePrettyJsonFormat'])
+@kate.action(**KATE_ACTIONS['togglePrettyJsonFormat'])
 def togglePrettyJsonFormat():
     currentDocument = kate.activeDocument()
     view = currentDocument.activeView()
@@ -23,8 +21,8 @@ def togglePrettyJsonFormat():
     try:
         target = pp.pformat(simplejson.loads(source))
         view.removeSelectionText()
-        utils.insertText(target.replace("'", '"'))
-    except JSONDecodeError:
+        insertText(target.replace("'", '"'))
+    except simplejson.JSONDecodeError:
         kate.gui.popup('This text is not a valid json text', 2,
                        icon='dialog-warning',
                        minTextWidth=200)
