@@ -1,11 +1,14 @@
-from kate_core_plugins import create_submenu
+from kate_core_plugins import create_submenu, separated_menu
 
+separated_menu('edit')
 DJ_MENU = create_submenu('Django Templates', 'django-templates', 'edit')
 PY_MENU = create_submenu('Python Templates', 'python-templates', 'edit')
 JS_MENU = create_submenu('Js Templates', 'js-templates', 'edit')
+separated_menu('edit')
+separated_menu('tools')
 CH_MENU = create_submenu('Checkers', 'checkers', 'tools')
 PR_MENU = create_submenu('Pretty print', 'pretty-print', 'tools')
-
+separated_menu('tools')
 
 KATE_ACTIONS = {
     'insertIPDB': {'text': 'ipdb', 'shortcut': 'Ctrl+I',
@@ -32,6 +35,10 @@ KATE_ACTIONS = {
                    'menu': DJ_MENU, 'icon': None},
     'importViews': {'text': 'Template import views', 'shortcut': 'Ctrl+Alt+v',
                     'menu': DJ_MENU, 'icon': None},
+    'createBlock': {'text': 'Template block', 'shortcut': 'Ctrl+Alt+B',
+                              'menu': DJ_MENU, 'icon': None},
+    'closeTemplateTag': {'text': 'Close Template tag', 'shortcut': 'Ctrl+Alt+C',
+                              'menu': DJ_MENU, 'icon': None},
     'insertReady': {'text': 'jQuery Ready', 'shortcut': 'Ctrl+J',
                     'menu': JS_MENU, 'icon': None},
     'checkJslint': {'text': 'JSLint', 'shortcut': 'Alt+J',
@@ -47,6 +54,8 @@ JAVASCRIPT_AUTOCOMPLETE_ENABLED = True
 JQUERY_AUTOCOMPLETE_ENABLED = True
 CHECKALL_TO_SAVE = True
 IGNORE_PEP8_ERRORS = []
+TEMPLATE_TAGS_CLOSE = ["autoescape", "block", "comment", "filter", "for", "if",
+                       "ifchanged", "ifequal", "spaceless", "with"]
 
 
 try:
